search
======

.. automodule:: translate.search
   :show-inheritance:


lshtein
-------

.. automodule:: translate.search.lshtein
   :members:
   :inherited-members:


match
-----

.. automodule:: translate.search.match
   :members:
   :inherited-members:


terminology
-----------

.. automodule:: translate.search.terminology
   :members:
   :inherited-members:
